@@ -1,17 +1,12 @@
 """Generated protocol buffer code."""
+from google.protobuf.internal import builder as _builder
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
-from google.protobuf import message as _message
-from google.protobuf import reflection as _reflection
 from google.protobuf import symbol_database as _symbol_database
 _sym_db = _symbol_database.Default()
 DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/mempool/types.proto\x12\x12tendermint.mempool"\x12\n\x03Txs\x12\x0b\n\x03txs\x18\x01 \x03(\x0c"8\n\x07Message\x12&\n\x03txs\x18\x01 \x01(\x0b2\x17.tendermint.mempool.TxsH\x00B\x05\n\x03sumB;Z9github.com/tendermint/tendermint/proto/tendermint/mempoolb\x06proto3')
-_TXS = DESCRIPTOR.message_types_by_name['Txs']
-_MESSAGE = DESCRIPTOR.message_types_by_name['Message']
-Txs = _reflection.GeneratedProtocolMessageType('Txs', (_message.Message,), {'DESCRIPTOR': _TXS, '__module__': 'tendermint.mempool.types_pb2'})
-_sym_db.RegisterMessage(Txs)
-Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {'DESCRIPTOR': _MESSAGE, '__module__': 'tendermint.mempool.types_pb2'})
-_sym_db.RegisterMessage(Message)
+_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
+_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.mempool.types_pb2', globals())
 if _descriptor._USE_C_DESCRIPTORS == False:
     DESCRIPTOR._options = None
     DESCRIPTOR._serialized_options = b'Z9github.com/tendermint/tendermint/proto/tendermint/mempool'
