@@ -1,14 +1,12 @@
 """Generated protocol buffer code."""
+from google.protobuf.internal import builder as _builder
 from google.protobuf import descriptor as _descriptor
 from google.protobuf import descriptor_pool as _descriptor_pool
-from google.protobuf import message as _message
-from google.protobuf import reflection as _reflection
 from google.protobuf import symbol_database as _symbol_database
 _sym_db = _symbol_database.Default()
 DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/types/events.proto\x12\x10tendermint.types"B\n\x13EventDataRoundState\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\tB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')
-_EVENTDATAROUNDSTATE = DESCRIPTOR.message_types_by_name['EventDataRoundState']
-EventDataRoundState = _reflection.GeneratedProtocolMessageType('EventDataRoundState', (_message.Message,), {'DESCRIPTOR': _EVENTDATAROUNDSTATE, '__module__': 'tendermint.types.events_pb2'})
-_sym_db.RegisterMessage(EventDataRoundState)
+_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
+_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.events_pb2', globals())
 if _descriptor._USE_C_DESCRIPTORS == False:
     DESCRIPTOR._options = None
     DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
